From 62eefec4762e6bbcd7f574709049eb2143883814 Mon Sep 17 00:00:00 2001
From: Michael Garcia <thecrazygm@gmail.com>
Date: Fri, 20 Mar 2020 18:12:14 -0500
Subject: [PATCH] steemit -> hiveit -> hiveio

---
 beem/account.py                              | 20 +++++++-------
 beem/blockchain.py                           |  4 +--
 beem/cli.py                                  |  2 +-
 beem/conveyor.py                             | 12 ++++-----
 beem/discussions.py                          |  8 +++---
 beem/imageuploader.py                        |  2 +-
 beem/utils.py                                |  2 +-
 beemapi/graphenerpc.py                       |  2 +-
 docs/apidefinitions.rst                      |  8 +++---
 docs/cli.rst                                 |  4 +--
 docs/tutorials.rst                           |  2 +-
 examples/compare_with_hive_python_account.py |  4 +--
 examples/hf20_testnet.py                     |  2 +-
 examples/memory_profiler2.py                 |  2 +-
 examples/print_appbase_calls.py              |  2 +-
 setup.py                                     |  4 +--
 tests/beem/test_amount.py                    |  4 +--
 tests/beem/test_asset.py                     | 12 ++++-----
 tests/beem/test_blockchain.py                |  6 ++---
 tests/beem/test_cli.py                       |  8 +++---
 tests/beem/test_comment.py                   |  4 +--
 tests/beem/test_connection.py                |  2 +-
 tests/beem/test_discussions.py               | 16 +++++------
 tests/beem/test_txbuffers.py                 |  4 +--
 tests/beem/test_utils.py                     |  2 +-
 tests/beem/test_witness.py                   | 28 ++++++++++----------
 tests/beemapi/test_steemnoderpc.py           |  6 ++---
 tests/beembase/test_transactions.py          |  2 +-
 28 files changed, 87 insertions(+), 87 deletions(-)

diff --git a/beem/blockchain.py b/beem/blockchain.py
index c0af6bcc..2b02699b 100644
--- a/beem/blockchain.py
+++ b/beem/blockchain.py
@@ -695,7 +695,7 @@ class Blockchain(object):
                     'from': 'johngreenfield',
                     'to': 'thundercurator',
                     'amount': '0.080 HBD',
-                    'memo': 'https://hiveit.com/lofi/@johngreenfield/lofi-joji-yeah-right',
+                    'memo': 'https://hive.blog/lofi/@johngreenfield/lofi-joji-yeah-right',
                     '_id': '6d4c5f2d4d8ef1918acaee4a8dce34f9da384786',
                     'timestamp': datetime.datetime(2018, 5, 9, 11, 23, 6, tzinfo=<UTC>),
                     'block_num': 22277588, 'trx_num': 35, 'trx_id': 'cf11b2ac8493c71063ec121b2e8517ab1e0e6bea'
@@ -713,7 +713,7 @@ class Blockchain(object):
                                 {
                                     'from': 'johngreenfield', 'to': 'thundercurator',
                                     'amount': '0.080 HBD',
-                                    'memo': 'https://hiveit.com/lofi/@johngreenfield/lofi-joji-yeah-right'
+                                    'memo': 'https://hive.blog/lofi/@johngreenfield/lofi-joji-yeah-right'
                                 }
                         ],
                         'timestamp': datetime.datetime(2018, 5, 9, 11, 23, 6, tzinfo=<UTC>)
diff --git a/beem/cli.py b/beem/cli.py
index cc9da990..346c9382 100644
--- a/beem/cli.py
+++ b/beem/cli.py
@@ -153,7 +153,7 @@ def node_answer_time(node):
 
 @click.group(chain=True)
 @click.option(
-    '--node', '-n', default="", help="URL for public Hive API (e.g. https://api.hiveit.com)")
+    '--node', '-n', default="", help="URL for public Hive API (e.g. https://api.hive.blog)")
 @click.option(
     '--offline', '-o', is_flag=True, default=False, help="Prevent connecting to network")
 @click.option(
diff --git a/beem/discussions.py b/beem/discussions.py
index 4f744ce2..16fbc9ec 100644
--- a/beem/discussions.py
+++ b/beem/discussions.py
@@ -32,7 +32,7 @@ class Query(dict):
         .. testcode::
 
             from beem.discussions import Query
-            query = Query(limit=10, tag="hiveit")
+            query = Query(limit=10, tag="hiveio")
 
     """
     def __init__(self, limit=0, tag="", truncate_body=0,
@@ -77,7 +77,7 @@ class Discussions(object):
             .. testcode::
 
                 from beem.discussions import Query, Discussions
-                query = Query(limit=51, tag="hiveit")
+                query = Query(limit=51, tag="hiveio")
                 discussions = Discussions()
                 count = 0
                 for d in discussions.get_discussions("tags", query, limit=200):
@@ -573,7 +573,7 @@ class Discussions_by_comments(list):
         .. testcode::
 
             from beem.discussions import Query, Discussions_by_comments
-            q = Query(limit=10, start_author="hiveit", start_permlink="firstpost")
+            q = Query(limit=10, start_author="hiveio", start_permlink="firstpost")
             for h in Discussions_by_comments(q):
                 print(h)
 
@@ -635,7 +635,7 @@ class Replies_by_last_update(list):
         .. testcode::
 
             from beem.discussions import Query, Replies_by_last_update
-            q = Query(limit=10, start_parent_author="hiveit", start_permlink="firstpost")
+            q = Query(limit=10, start_parent_author="hiveio", start_permlink="firstpost")
             for h in Replies_by_last_update(q):
                 print(h)
 
diff --git a/beem/imageuploader.py b/beem/imageuploader.py
index bd67878a..63b88f41 100644
--- a/beem/imageuploader.py
+++ b/beem/imageuploader.py
@@ -20,7 +20,7 @@ from beemgraphenebase.ecdsasig import sign_message, verify_message
 class ImageUploader(object):
     def __init__(
         self,
-        base_url="https://hiveitimages.com",
+        base_url="https://hiveitimages.com", #TODO
         challenge="ImageSigningChallenge",
         hive_instance=None,
     ):
diff --git a/beem/utils.py b/beem/utils.py
index 1ca484aa..e6a2d13c 100644
--- a/beem/utils.py
+++ b/beem/utils.py
@@ -148,7 +148,7 @@ def resolve_authorperm(identifier):
 
             >>> from beem.utils import resolve_authorperm
             >>> author, permlink = resolve_authorperm('https://d.tube/#!/v/pottlund/m5cqkd1a')
-            >>> author, permlink = resolve_authorperm("https://hiveit.com/witness-category/@gtg/24lfrm-gtg-witness-log")
+            >>> author, permlink = resolve_authorperm("https://hive.blog/witness-category/@gtg/24lfrm-gtg-witness-log")
             >>> author, permlink = resolve_authorperm("@gtg/24lfrm-gtg-witness-log")
             >>> author, permlink = resolve_authorperm("https://busy.org/@gtg/24lfrm-gtg-witness-log")
 
diff --git a/beemapi/graphenerpc.py b/beemapi/graphenerpc.py
index 2fb108f5..e3108196 100644
--- a/beemapi/graphenerpc.py
+++ b/beemapi/graphenerpc.py
@@ -115,7 +115,7 @@ class GrapheneRPC(object):
             ws = GrapheneRPC("wss://hived.pevo.science","","")
             print(ws.get_account_count())
 
-            ws = GrapheneRPC("https://api.hiveit.com","","")
+            ws = GrapheneRPC("https://api.hive.blog","","")
             print(ws.get_account_count())
 
     .. note:: This class allows to call methods available via
diff --git a/docs/apidefinitions.rst b/docs/apidefinitions.rst
index 89a5ac9c..1642ae84 100644
--- a/docs/apidefinitions.rst
+++ b/docs/apidefinitions.rst
@@ -50,7 +50,7 @@ get_account_history
 .. code-block:: python
 
     from beem.account import Account
-    acc = Account("hiveit")
+    acc = Account("hiveio")
     for h in acc.get_account_history(1,0):
         print(h)
 
@@ -267,7 +267,7 @@ get_discussions_by_comments
 .. code-block:: python
 
     from beem.discussions import Query, Discussions_by_comments
-    q = Query(limit=10, start_author="hiveit", start_permlink="firstpost")
+    q = Query(limit=10, start_author="hiveio", start_permlink="firstpost")
     for h in Discussions_by_comments(q):
         print(h)
 
@@ -563,7 +563,7 @@ get_replies_by_last_update
 .. code-block:: python
 
     from beem.discussions import Query, Replies_by_last_update
-    q = Query(limit=10, start_author="hiveit", start_permlink="firstpost")
+    q = Query(limit=10, start_author="hiveio", start_permlink="firstpost")
     for h in Replies_by_last_update(q):
         print(h)
 
@@ -670,7 +670,7 @@ get_trending_tags
 .. code-block:: python
 
     from beem.discussions import Query, Trending_tags
-    q = Query(limit=10, start_tag="hiveit")
+    q = Query(limit=10, start_tag="hiveio")
     for h in Trending_tags(q):
         print(h)
 
diff --git a/docs/cli.rst b/docs/cli.rst
index 91a9e494..ae04b5b6 100644
--- a/docs/cli.rst
+++ b/docs/cli.rst
@@ -63,7 +63,7 @@ Upvoting a post:
 
 ::
 
-   beempy upvote --account <account_name> https://hiveit.com/funny/@mynameisbrian/the-content-stand-a-comic
+   beempy upvote --account <account_name> https://hive.blog/funny/@mynameisbrian/the-content-stand-a-comic
 
 
 Setting Defaults
@@ -108,7 +108,7 @@ You can see all available commands with ``beempy --help``
 
    Options:
      -n, --node TEXT        URL for public Hive API (e.g.
-                            https://api.hiveit.com)
+                            https://api.hive.blog)
      -o, --offline          Prevent connecting to network
      -d, --no-broadcast     Do not broadcast
      -p, --no-wallet        Do not load the wallet
diff --git a/docs/tutorials.rst b/docs/tutorials.rst
index e4bbe55c..ab4072e5 100644
--- a/docs/tutorials.rst
+++ b/docs/tutorials.rst
@@ -208,7 +208,7 @@ the complete queue is sended at once to the node. The result is a list with repl
 .. code-block:: python
 
     from beem import Hive
-    hv = Hive("https://api.hiveit.com")
+    hv = Hive("https://api.hive.blog")
     hv.rpc.get_config(add_to_queue=True)
     hv.rpc.rpc_queue
 
diff --git a/examples/compare_with_hive_python_account.py b/examples/compare_with_hive_python_account.py
index 206e1d5f..7802e3d0 100644
--- a/examples/compare_with_hive_python_account.py
+++ b/examples/compare_with_hive_python_account.py
@@ -16,9 +16,9 @@ logging.basicConfig(level=logging.INFO)
 
 
 if __name__ == "__main__":
-    hv = Hive("https://api.hiveit.com")
+    hv = Hive("https://api.hive.blog")
     beem_acc = Account("thecrazygm", hive_instance=hv)
-    hv2 = hiveHive(nodes=["https://api.hiveit.com"])
+    hv2 = hiveHive(nodes=["https://api.hive.blog"])
     hive_acc = hiveAccount("thecrazygm", hived_instance=hv2)
 
     # profile
diff --git a/examples/hf20_testnet.py b/examples/hf20_testnet.py
index 7e8af750..d1920eff 100644
--- a/examples/hf20_testnet.py
+++ b/examples/hf20_testnet.py
@@ -24,7 +24,7 @@ logging.basicConfig(level=logging.INFO)
 if __name__ == "__main__":
     # hv = Hive(node="https://testnet.timcliff.com/")
     # hv = Hive(node="https://testnet.hiveitdev.com")
-    hv = Hive(node="https://api.hiveit.com")
+    hv = Hive(node="https://api.hive.blog")
     hv.wallet.unlock(pwd="pwd123")
 
     account = Account("beembot", hive_instance=hv)
diff --git a/examples/memory_profiler2.py b/examples/memory_profiler2.py
index 8c1ed94f..062903c2 100644
--- a/examples/memory_profiler2.py
+++ b/examples/memory_profiler2.py
@@ -45,7 +45,7 @@ if __name__ == "__main__":
     shared_instance = False
     clear_acc_cache = False
     clear_all_cache = False
-    node = "https://api.hiveit.com"
+    node = "https://api.hive.blog"
     n = 3
     for i in range(1, n + 1):
         print("%d of %d" % (i, n))
diff --git a/examples/print_appbase_calls.py b/examples/print_appbase_calls.py
index 6c26d0c2..0368e64b 100644
--- a/examples/print_appbase_calls.py
+++ b/examples/print_appbase_calls.py
@@ -15,7 +15,7 @@ logging.basicConfig(level=logging.INFO)
 
 
 if __name__ == "__main__":
-    hv = Hive(node="https://api.hiveit.com")
+    hv = Hive(node="https://api.hive.blog")
     # hv = Hive(node="https://testnet.hiveitdev.com")
     # hv = Hive(node="wss://appbasetest.timcliff.com")
     # hv = Hive(node="https://api.hiveitstage.com")
diff --git a/setup.py b/setup.py
index cc38dcc4..ea9890a7 100755
--- a/setup.py
+++ b/setup.py
@@ -70,9 +70,9 @@ if __name__ == '__main__':
         long_description=get_long_description(),
         download_url='https://github.com/thecrazygmn/beem/tarball/' + VERSION,
         author='Holger Nahrstaedt',
-        author_email='thecrazygm@nahrstaedt.de',
+        author_email='thecrazygm@gmail.com',
         maintainer='Holger Nahrstaedt',
-        maintainer_email='thecrazygm@nahrstaedt.de',
+        maintainer_email='thecrazygm@gmail.com',
         url='http://www.github.com/thecrazygmn/beem',
         keywords=['hive', 'library', 'api', 'rpc'],
         packages=[
diff --git a/tests/beem/test_amount.py b/tests/beem/test_amount.py
index a5b78b3d..e46bf31c 100644
--- a/tests/beem/test_amount.py
+++ b/tests/beem/test_amount.py
@@ -23,8 +23,8 @@ class Testcases(unittest.TestCase):
             nobroadcast=True,
             num_retries=10
         )
-        cls.hiveit = Steem(
-            node="https://api.hiveit.com",
+        cls.hiveio = Steem(
+            node="https://api.hive.blog",
             nobroadcast=True,
             use_condenser=False,
             num_retries=10
diff --git a/tests/beem/test_asset.py b/tests/beem/test_asset.py
index d133e8c6..0155f82e 100644
--- a/tests/beem/test_asset.py
+++ b/tests/beem/test_asset.py
@@ -23,8 +23,8 @@ class Testcases(unittest.TestCase):
             nobroadcast=True,
             num_retries=10
         )
-        cls.hiveit = Steem(
-            node="https://api.hiveit.com",
+        cls.hiveio = Steem(
+            node="https://api.hive.blog",
             nobroadcast=True,
             num_retries=10
         )
@@ -32,13 +32,13 @@ class Testcases(unittest.TestCase):
 
     @parameterized.expand([
         ("normal"),
-        ("hiveit"),
+        ("hiveio"),
     ])
     def test_assert(self, node_param):
         if node_param == "normal":
             hv = self.bts
         else:
-            hv = self.hiveit
+            hv = self.hiveio
         with self.assertRaises(AssetDoesNotExistsException):
             Asset("FOObarNonExisting", full=False, hive_instance=hv)
 
@@ -62,13 +62,13 @@ class Testcases(unittest.TestCase):
 
     @parameterized.expand([
         ("normal"),
-        ("hiveit"),
+        ("hiveio"),
     ])
     def test_assert_equal(self, node_param):
         if node_param == "normal":
             hv = self.bts
         else:
-            hv = self.hiveit
+            hv = self.hiveio
         asset1 = Asset("HBD", full=False, hive_instance=hv)
         asset2 = Asset("HBD", full=False, hive_instance=hv)
         self.assertTrue(asset1 == asset2)
diff --git a/tests/beem/test_blockchain.py b/tests/beem/test_blockchain.py
index 23e3bd15..8d6a929a 100644
--- a/tests/beem/test_blockchain.py
+++ b/tests/beem/test_blockchain.py
@@ -18,7 +18,7 @@ from beem.nodelist import NodeList
 from beembase.signedtransactions import Signed_Transaction
 
 wif = "5KQwrPbwdL6PhXujxW37FSSQZ1JiwsST4cqQzDeyXtP79zkvFD3"
-nodes_appbase = ["https://api.hiveitstage.com", "https://api.hive.house", "https://api.hiveit.com"]
+nodes_appbase = ["https://api.hiveitstage.com", "https://api.hive.house", "https://api.hive.blog"]
 
 
 class Testcases(unittest.TestCase):
@@ -221,8 +221,8 @@ class Testcases(unittest.TestCase):
     def test_hash_op(self):
         bts = self.bts
         b = Blockchain(hive_instance=bts)
-        op1 = {'type': 'vote_operation', 'value': {'voter': 'ubg', 'author': 'yesslife', 'permlink': 'hiveit-sandwich-contest-week-25-2da-entry', 'weight': 100}}
-        op2 = ['vote', {'voter': 'ubg', 'author': 'yesslife', 'permlink': 'hiveit-sandwich-contest-week-25-2da-entry', 'weight': 100}]
+        op1 = {'type': 'vote_operation', 'value': {'voter': 'ubg', 'author': 'yesslife', 'permlink': 'hiveio-sandwich-contest-week-25-2da-entry', 'weight': 100}}
+        op2 = ['vote', {'voter': 'ubg', 'author': 'yesslife', 'permlink': 'hiveio-sandwich-contest-week-25-2da-entry', 'weight': 100}]
         hash1 = b.hash_op(op1)
         hash2 = b.hash_op(op2)
         self.assertEqual(hash1, hash2)
diff --git a/tests/beem/test_cli.py b/tests/beem/test_cli.py
index 56611968..19d3107b 100644
--- a/tests/beem/test_cli.py
+++ b/tests/beem/test_cli.py
@@ -154,14 +154,14 @@ class Testcases(unittest.TestCase):
 
     def test_upvote(self):
         runner = CliRunner()
-        result = runner.invoke(cli, ['-ds', 'upvote', '@hiveit/firstpost'], input="test\n")
+        result = runner.invoke(cli, ['-ds', 'upvote', '@hiveio/firstpost'], input="test\n")
         self.assertEqual(result.exit_code, 0)
-        result = runner.invoke(cli, ['-ds', 'upvote', '--weight', '100', '@hiveit/firstpost'], input="test\n")
+        result = runner.invoke(cli, ['-ds', 'upvote', '--weight', '100', '@hiveio/firstpost'], input="test\n")
         self.assertEqual(result.exit_code, 0)
 
     def test_downvote(self):
         runner = CliRunner()
-        result = runner.invoke(cli, ['-ds', 'downvote', '--weight', '100', '@hiveit/firstpost'], input="test\n")
+        result = runner.invoke(cli, ['-ds', 'downvote', '--weight', '100', '@hiveio/firstpost'], input="test\n")
         self.assertEqual(result.exit_code, 0)
 
     def test_transfer(self):
@@ -315,7 +315,7 @@ class Testcases(unittest.TestCase):
 
     def test_rehive(self):
         runner = CliRunner()
-        result = runner.invoke(cli, ['-dso', 'rehive', '@hiveit/firstposte'], input="test\n")
+        result = runner.invoke(cli, ['-dso', 'rehive', '@hiveio/firstposte'], input="test\n")
         self.assertEqual(result.exit_code, 0)
 
     def test_follow_unfollow(self):
diff --git a/tests/beem/test_comment.py b/tests/beem/test_comment.py
index 6d32196a..cb5beaea 100644
--- a/tests/beem/test_comment.py
+++ b/tests/beem/test_comment.py
@@ -32,8 +32,8 @@ class Testcases(unittest.TestCase):
             keys={"active": wif},
             num_retries=10
         )
-        cls.hiveit = Steem(
-            node="https://api.hiveit.com",
+        cls.hiveio = Steem(
+            node="https://api.hive.blog",
             nobroadcast=True,
             unsigned=True,
             keys={"active": wif},
diff --git a/tests/beem/test_connection.py b/tests/beem/test_connection.py
index b91d192e..5bb785cc 100644
--- a/tests/beem/test_connection.py
+++ b/tests/beem/test_connection.py
@@ -15,7 +15,7 @@ class Testcases(unittest.TestCase):
         nodelist = NodeList()
         nodelist.update_nodes(hive_instance=Steem(node=nodelist.get_nodes(exclude_limited=False), num_retries=10))
         b1 = Steem(
-            node="https://api.hiveit.com",
+            node="https://api.hive.blog",
             nobroadcast=True,
             num_retries=10
         )
diff --git a/tests/beem/test_discussions.py b/tests/beem/test_discussions.py
index 205c70eb..94c465d9 100644
--- a/tests/beem/test_discussions.py
+++ b/tests/beem/test_discussions.py
@@ -44,7 +44,7 @@ class Testcases(unittest.TestCase):
         bts = self.bts
         query = Query()
         query["limit"] = 10
-        query["tag"] = "hiveit"
+        query["tag"] = "hiveio"
         d = Discussions_by_trending(query, hive_instance=bts)
         self.assertEqual(len(d), 10)
 
@@ -52,7 +52,7 @@ class Testcases(unittest.TestCase):
         bts = self.bts
         query = Query()
         query["limit"] = 10
-        query["tag"] = "hiveit"
+        query["tag"] = "hiveio"
         d = Comment_discussions_by_payout(query, hive_instance=bts)
         self.assertEqual(len(d), 10)
 
@@ -61,7 +61,7 @@ class Testcases(unittest.TestCase):
 
         query = Query()
         query["limit"] = 10
-        query["tag"] = "hiveit"
+        query["tag"] = "hiveio"
         d = Post_discussions_by_payout(query, hive_instance=bts)
         self.assertEqual(len(d), 10)
 
@@ -69,7 +69,7 @@ class Testcases(unittest.TestCase):
         bts = self.bts
         query = Query()
         query["limit"] = 10
-        query["tag"] = "hiveit"
+        query["tag"] = "hiveio"
         d = Discussions_by_created(query, hive_instance=bts)
         self.assertEqual(len(d), 10)
 
@@ -77,7 +77,7 @@ class Testcases(unittest.TestCase):
         bts = self.bts
         query = Query()
         query["limit"] = 10
-        query["tag"] = "hiveit"
+        query["tag"] = "hiveio"
         d = Discussions_by_active(query, hive_instance=bts)
         self.assertEqual(len(d), 10)
 
@@ -91,7 +91,7 @@ class Testcases(unittest.TestCase):
         bts = self.bts
         query = Query()
         query["limit"] = 10
-        query["tag"] = "hiveit"
+        query["tag"] = "hiveio"
         d = Discussions_by_votes(query, hive_instance=bts)
         self.assertEqual(len(d), 10)
 
@@ -99,7 +99,7 @@ class Testcases(unittest.TestCase):
         bts = self.bts
         query = Query()
         query["limit"] = 10
-        query["tag"] = "hiveit"
+        query["tag"] = "hiveio"
         d = Discussions_by_children(query, hive_instance=bts)
         self.assertEqual(len(d), 10)
 
@@ -132,7 +132,7 @@ class Testcases(unittest.TestCase):
         bts = self.bts
         query = Query()
         query["limit"] = 1
-        query["tag"] = "hiveit"
+        query["tag"] = "hiveio"
         d = Discussions_by_promoted(query, hive_instance=bts)
         discussions = Discussions(hive_instance=bts)
         d2 = []
diff --git a/tests/beem/test_txbuffers.py b/tests/beem/test_txbuffers.py
index ad6a7d10..97524988 100644
--- a/tests/beem/test_txbuffers.py
+++ b/tests/beem/test_txbuffers.py
@@ -40,8 +40,8 @@ class Testcases(unittest.TestCase):
             nobroadcast=True,
             num_retries=10
         )
-        cls.hiveit = Steem(
-            node="https://api.hiveit.com",
+        cls.hiveio = Steem(
+            node="https://api.hive.blog",
             nobroadcast=True,
             keys={"active": wif, "owner": wif, "memo": wif},
             num_retries=10
diff --git a/tests/beem/test_utils.py b/tests/beem/test_utils.py
index 78dd296f..f9589293 100644
--- a/tests/beem/test_utils.py
+++ b/tests/beem/test_utils.py
@@ -45,7 +45,7 @@ class Testcases(unittest.TestCase):
     def test_authorperm_resolve(self):
         self.assertEqual(resolve_authorperm('https://d.tube/#!/v/pottlund/m5cqkd1a'),
                          ('pottlund', 'm5cqkd1a'))
-        self.assertEqual(resolve_authorperm("https://hiveit.com/witness-category/@gtg/24lfrm-gtg-witness-log"),
+        self.assertEqual(resolve_authorperm("https://hive.blog/witness-category/@gtg/24lfrm-gtg-witness-log"),
                          ('gtg', '24lfrm-gtg-witness-log'))
         self.assertEqual(resolve_authorperm("@gtg/24lfrm-gtg-witness-log"),
                          ('gtg', '24lfrm-gtg-witness-log'))
diff --git a/tests/beem/test_witness.py b/tests/beem/test_witness.py
index 36f8d462..2048765c 100644
--- a/tests/beem/test_witness.py
+++ b/tests/beem/test_witness.py
@@ -26,8 +26,8 @@ class Testcases(unittest.TestCase):
             keys={"active": wif},
             num_retries=10
         )
-        cls.hiveit = Steem(
-            node="https://api.hiveit.com",
+        cls.hiveio = Steem(
+            node="https://api.hive.blog",
             nobroadcast=True,
             unsigned=True,
             keys={"active": wif},
@@ -40,13 +40,13 @@ class Testcases(unittest.TestCase):
 
     @parameterized.expand([
         ("normal"),
-        ("hiveit"),
+        ("hiveio"),
     ])
     def test_feed_publish(self, node_param):
         if node_param == "normal":
             bts = self.bts
         else:
-            bts = self.hiveit
+            bts = self.hiveio
         bts.txbuffer.clear()
         w = Witness("gtg", hive_instance=bts)
         tx = w.feed_publish("4 HBD", "1 HIVE")
@@ -61,13 +61,13 @@ class Testcases(unittest.TestCase):
 
     @parameterized.expand([
         ("normal"),
-        ("hiveit"),
+        ("hiveio"),
     ])
     def test_update(self, node_param):
         if node_param == "normal":
             bts = self.bts
         else:
-            bts = self.hiveit
+            bts = self.hiveio
         bts.txbuffer.clear()
         w = Witness("gtg", hive_instance=bts)
         props = {"account_creation_fee": "0.1 HIVE",
@@ -82,13 +82,13 @@ class Testcases(unittest.TestCase):
 
     @parameterized.expand([
         ("normal"),
-        ("hiveit"),
+        ("hiveio"),
     ])
     def test_witnesses(self, node_param):
         if node_param == "normal":
             bts = self.bts
         else:
-            bts = self.hiveit
+            bts = self.hiveio
         w = Witnesses(hive_instance=bts)
         w.printAsTable()
         self.assertTrue(len(w) > 0)
@@ -96,13 +96,13 @@ class Testcases(unittest.TestCase):
 
     @parameterized.expand([
         ("normal"),
-        ("hiveit"),
+        ("hiveio"),
     ])
     def test_WitnessesVotedByAccount(self, node_param):
         if node_param == "normal":
             bts = self.bts
         else:
-            bts = self.hiveit
+            bts = self.hiveio
         w = WitnessesVotedByAccount("gtg", hive_instance=bts)
         w.printAsTable()
         self.assertTrue(len(w) > 0)
@@ -110,13 +110,13 @@ class Testcases(unittest.TestCase):
 
     @parameterized.expand([
         ("normal"),
-        ("hiveit"),
+        ("hiveio"),
     ])
     def test_WitnessesRankedByVote(self, node_param):
         if node_param == "normal":
             bts = self.bts
         else:
-            bts = self.hiveit
+            bts = self.hiveio
         w = WitnessesRankedByVote(hive_instance=bts)
         w.printAsTable()
         self.assertTrue(len(w) > 0)
@@ -124,13 +124,13 @@ class Testcases(unittest.TestCase):
 
     @parameterized.expand([
         ("normal"),
-        ("hiveit"),
+        ("hiveio"),
     ])
     def test_export(self, node_param):
         if node_param == "normal":
             bts = self.bts
         else:
-            bts = self.hiveit
+            bts = self.hiveio
         owner = "gtg"
         if bts.rpc.get_use_appbase():
             witness = bts.rpc.find_witnesses({'owners': [owner]}, api="database")['witnesses']
diff --git a/tests/beemapi/test_steemnoderpc.py b/tests/beemapi/test_steemnoderpc.py
index 588d13f9..d1a7081d 100644
--- a/tests/beemapi/test_steemnoderpc.py
+++ b/tests/beemapi/test_steemnoderpc.py
@@ -33,9 +33,9 @@ class Testcases(unittest.TestCase):
         nodelist = NodeList()
         nodelist.update_nodes(hive_instance=Steem(node=nodelist.get_nodes(normal=True, appbase=True), num_retries=3))
         cls.nodes = nodelist.get_nodes()
-        if "https://api.hiveit.com" in cls.nodes:
-            cls.nodes.remove("https://api.hiveit.com")
-        cls.nodes_hiveit = ["https://api.hiveit.com"]
+        if "https://api.hive.blog" in cls.nodes:
+            cls.nodes.remove("https://api.hive.blog")
+        cls.nodes_hiveit = ["https://api.hive.blog"]
 
         cls.appbase = Steem(
             node=cls.nodes,
diff --git a/tests/beembase/test_transactions.py b/tests/beembase/test_transactions.py
index e4fadbf3..e6133ec8 100644
--- a/tests/beembase/test_transactions.py
+++ b/tests/beembase/test_transactions.py
@@ -992,7 +992,7 @@ class Testcases(unittest.TestCase):
             **{
                 "fee": {"amount": "3000", "precision": 3, "nai": "@@000000021"},
                 "delegation": {"amount": "0", "precision": 6, "nai": "@@000000037"},
-                "creator": "hiveit",
+                "creator": "hiveio",
                 "new_account_name": "alice",
                 "owner": {
                     "weight_threshold": 1,
diff --git a/beem/account.py b/beem/account.py
index b2d9a3df..f37e09b2 100644
--- a/beem/account.py
+++ b/beem/account.py
@@ -388,7 +388,7 @@ class Account(BlockchainObject):
             print(ret)
 
     def get_reputation(self):
         """ Returns the account reputation in the (hiveit) normalized form
         """
         if not self.hive.is_connected():
             return None
@@ -661,7 +661,7 @@ class Account(BlockchainObject):
                 >>> from beem.account import Account
                 >>> from beem import Hive
                 >>> hv = Hive()
-                >>> account = Account("hiveit", hive_instance=hv)
+                >>> account = Account("hiveio", hive_instance=hv)
                 >>> account.get_feed(0, 1, raw_data=True)
                 []
 
@@ -723,7 +723,7 @@ class Account(BlockchainObject):
                 >>> from beem.account import Account
                 >>> from beem import Hive
                 >>> hv = Hive()
-                >>> account = Account("hiveit", hive_instance=hv)
+                >>> account = Account("hiveio", hive_instance=hv)
                 >>> account.get_feed_entries(0, 1)
                 []
 
@@ -746,10 +746,10 @@ class Account(BlockchainObject):
                 >>> from beem.account import Account
                 >>> from beem import Hive
                 >>> hv = Hive()
-                >>> account = Account("hiveit", hive_instance=hv)
+                >>> account = Account("hiveio", hive_instance=hv)
                 >>> entry = account.get_blog_entries(0, 1, raw_data=True)[0]
                 >>> print("%s - %s - %s - %s" % (entry["author"], entry["permlink"], entry["blog"], entry["reblog_on"]))
-                hiveit - firstpost - hiveit - 1970-01-01T00:00:00
+                hiveio - firstpost - hiveio - 1970-01-01T00:00:00
 
         """
         return self.get_blog(start_entry_id=start_entry_id, limit=limit, raw_data=raw_data, short_entries=True, account=account)
@@ -770,9 +770,9 @@ class Account(BlockchainObject):
                 >>> from beem.account import Account
                 >>> from beem import Hive
                 >>> hv = Hive()
-                >>> account = Account("hiveit", hive_instance=hv)
+                >>> account = Account("hiveio", hive_instance=hv)
                 >>> account.get_blog(0, 1)
-                [<Comment @hiveit/firstpost>]
+                [<Comment @hiveio/firstpost>]
 
         """
         if account is None:
@@ -839,7 +839,7 @@ class Account(BlockchainObject):
                 >>> from beem.account import Account
                 >>> from beem import Hive
                 >>> hv = Hive()
-                >>> account = Account("hiveit", hive_instance=hv)
+                >>> account = Account("hiveio", hive_instance=hv)
                 >>> account.get_blog_authors()
                 []
 
@@ -1393,7 +1393,7 @@ class Account(BlockchainObject):
             .. code-block:: python
 
                 >>> from beem.account import Account
-                >>> account = Account("hiveit")
+                >>> account = Account("hiveio")
                 >>> print(account.verify_account_authority(["STM7Q2rLBqzPzFeteQZewv9Lu3NLE69fZoLeL6YK59t7UmssCBNTU"])["valid"])
                 False
 
@@ -3047,7 +3047,7 @@ class Account(BlockchainObject):
             .. code-block:: python
 
                 from beem.account import Account
-                acc = Account("hiveitblog")
+                acc = Account("hiveioblog")
                 for post in acc.blog_history(limit=10):
                     print(post)
 
@@ -388,7 +388,7 @@ class Account(BlockchainObject):
 
     def get_reputation(self):
-        """ Returns the account reputation in the (hiveit) normalized form
+        """ Returns the account reputation in the (hiveio) normalized form
         """
         if not self.hive.is_connected():
diff --git a/beem/conveyor.py b/beem/conveyor.py
index e29a6796..63c95785 100644
--- a/beem/conveyor.py
+++ b/beem/conveyor.py
@@ -22,8 +22,8 @@ except ImportError:
 
 
 class Conveyor(object):
-    """ Class to access Hiveit Conveyor instances:
-        https://github.com/hiveit/conveyor
+    """ Class to access hiveio Conveyor instances:
+        https://github.com/hiveio/conveyor
 
         Description from the official documentation:
 
@@ -42,15 +42,15 @@ class Conveyor(object):
           consisting of a post title and a body.
 
         The underlying RPC authentication and request signing procedure is
-        described here: https://github.com/hiveit/rpc-auth
+        described here: https://github.com/hiveio/rpc-auth
 
     """
 
-    def __init__(self, url="https://conveyor.hiveit.com",
+    def __init__(self, url="https://conveyor.hive.blog",
                  hive_instance=None):
         """ Initialize a Conveyor instance
             :param str url: (optional) URL to the Conveyor API, defaults to
-                https://conveyor.hiveit.com
+                https://conveyor.hive.blog
             :param beem.hive.Hive hive_instance: Hive instance
 
         """
@@ -65,7 +65,7 @@ class Conveyor(object):
 
     def prehash_message(self, timestamp, account, method, params, nonce):
         """ Prepare a hash for the Conveyor API request with SHA256 according
-            to https://github.com/hiveit/rpc-auth
+            to https://github.com/hiveio/rpc-auth
             Hashing of `second` is then done inside `ecdsasig.sign_message()`.
 
             :param str timestamp: valid iso8601 datetime ending in "Z"
-- 
GitLab